# Load libraries
library(tidyverse)
library(vegan)
library(cowplot)
library(FD)
`%!in%` <- negate(`%in%`)

# Set seed
set.seed(10312022)

# Load in the community data, drop traps with no species data
comm <- read.csv("comm.csv") %>%
  dplyr::mutate(abun=rowSums(dplyr::select(., contains(".")))) %>%
  dplyr::filter(abun!=0) %>%
  dplyr::group_by(Treatment, Year) %>%
  dplyr::mutate(trapWeek=row_number()) %>%
  ungroup()

comm_mat <- as.matrix(dplyr::select(comm, contains(".")))
comm_mat <- vegan::decostand(comm_mat, method="total")

# Taxonomic NMDS + PERMANOVA
tax_mds <- vegan::metaMDS(comm_mat, k=2, trymax=1000) # don't run again

tax_adon_treat <- vegan::adonis2(comm_mat~treatment+year+trapWeek, 
                                 data=data.frame(treatment=comm$Treatment,
                                                 year=comm$Year,
                                                 trapWeek=as.factor(comm$trapWeek)),
                                 permutations=10000)
pairwiseAdonis::pairwise.adonis2(comm_mat~treatment,
                                 data=data.frame(treatment=comm$Treatment,
                                                 year=comm$Year,
                                                 trapWeek=as.factor(comm$trapWeek)),
                                 nperm=10000)
envfit(tax_mds, env=comm$trapWeek, permutations=10000)

# Functional NMDS + PERMANOVA
trait <- read.csv("traits.csv") %>%
  dplyr::filter(Code!="Scaph")
trait <- trait[match(colnames(comm_mat), trait$Code),]
rownames(trait) <- trait$Code
trait <- dplyr::select(trait, -Code)
trait_mat <- FD::functcomp(trait, comm_mat, CWM.type="all")
trait_mds <- vegan::metaMDS(trait_mat, k=2, trymax=1000) # don't run again

trait_adon_treat <- vegan::adonis2(trait_mat~treatment+year+trapWeek, 
                                   data=data.frame(treatment=comm$Treatment,
                                                   year=comm$Year,
                                                   trapWeek=as.factor(comm$trapWeek)),
                                   permutations=10000)
pairwiseAdonis::pairwise.adonis2(trait_mat~treatment,
                                 data=data.frame(treatment=comm$Treatment,
                                                 year=comm$Year,
                                                 trapWeek=as.factor(comm$trapWeek)),
                                 nperm=10000)
envfit(trait_mds, env=comm$trapWeek, permutations=10000)

# Create Figure 3
tax_df <- data.frame(NMDS1=tax_mds$points[,1], NMDS2=tax_mds$points[,2],
                     Treatment=comm$Treatment, Year=comm$Year, TrapWeek=comm$trapWeek)
trait_df <- data.frame(NMDS1=trait_mds$points[,1], NMDS2=trait_mds$points[,2],
                       Treatment=comm$Treatment, Year=comm$Year, TrapWeek=comm$trapWeek)

figure_3_a <- ggordiplots::gg_ordiplot(tax_mds, groups=comm$Treatment)$plot+
  geom_text(as.data.frame(tax_mds$species),
            mapping=aes(x=MDS1, y=MDS2, label=
                          gsub(".*_", "", rownames(tax_mds$species))), alpha=0.5,
            size=3.5)+
  scale_color_manual(values=c("Control"="#44aa99", "Mid"="#ddcc77", "High"="#882255"),
                     labels=c("Control", "Mod", "High"))+
  scale_shape_manual(values=c("Control"=19, "Mid"=17, "High"=15))+
  labs(x="NMDS1", y="NMDS2")+
  theme_cowplot()+
  theme(legend.position="none",
        axis.title=element_text(size=18),
        axis.text=element_text(size=16))

figure_3_b <- ggordiplots::gg_ordiplot(trait_mds, groups=comm$Treatment)$plot+
  geom_text(as.data.frame(trait_mds$species),
            mapping=aes(x=MDS1, y=MDS2, label=
                          gsub("..", ".", 
                               gsub("1", "Fav. Human", gsub("0", "Unfav. Human", 
                                                            gsub("Unknown", "", 
                                                                 gsub(".*_", "", 
                                                                      rownames(trait_mds$species))))), fixed=TRUE)), alpha=0.5,
            size=3.5)+
  scale_color_manual(values=c("Control"="#44aa99", "Mid"="#ddcc77", "High"="#882255"),
                     labels=c("Control", "Mod", "High"))+
  scale_shape_manual(values=c("Control"=19, "Mid"=17, "High"=15),
                     labels=c("Control", "Mod", "High"))+
  labs(x="NMDS1", y="")+
  theme_cowplot()+
  theme(legend.position=c(0.8,0.15),
        axis.title=element_text(size=18),
        axis.text=element_text(size=16))

figure_3 <- cowplot::plot_grid(figure_3_a, figure_3_b,
                               ncol=2, labels=c("(a)", "(b)"), align="hv")
ggsave2("figure_3.png", figure_3, dpi=400, height=5, width=11)

# Create Figure 4

figure_4_a <- ggordiplots::gg_ordiplot(tax_mds, groups=comm$Year)$plot+
  geom_text(as.data.frame(tax_mds$species),
            mapping=aes(x=MDS1, y=MDS2, label=rownames(tax_mds$species)), alpha=0.5, size=3.5)+
  scale_color_manual(values=c("2017"="#44aa99", "2018"="#ddcc77"))+
  scale_shape_manual(values=c("2017"=19, "2018"=17))+
  labs(x="", y="NMDS2")+
  theme_cowplot()+
  theme(legend.position="none",
        axis.title=element_text(size=18),
        axis.text=element_text(size=16))

figure_4_b <- ggordiplots::gg_ordiplot(trait_mds, groups=comm$Year)$plot+
  geom_text(as.data.frame(trait_mds$species),
            mapping=aes(x=MDS1, y=MDS2, label=
                          gsub("..", ".", 
                               gsub("1", "Fav. Human", gsub("0", "Unfav. Human", 
                                                            gsub("Unknown", "", 
                                                                 gsub(".*_", "", 
                                                                      rownames(trait_mds$species))))), fixed=TRUE)), alpha=0.5,
            size=3.5)+
  scale_color_manual(values=c("2017"="#44aa99", "2018"="#ddcc77"), name="Year")+
  scale_shape_manual(values=c("2017"=19, "2018"=17), name="Year")+
  labs(x="", y="")+
  theme_cowplot()+
  theme(legend.position=c(0.8,0.15),
        axis.title=element_text(size=18),
        axis.text=element_text(size=16))

figure_4_c <- ggordiplots::gg_ordiplot(tax_mds, groups=comm$trapWeek)$plot+
  geom_text(as.data.frame(tax_mds$species),
            mapping=aes(x=MDS1, y=MDS2, label=rownames(tax_mds$species)), alpha=0.5,
            size=3.5)+
  colorspace::scale_color_discrete_diverging(palette="Berlin", name="Trap Week")+
  labs(x="NMDS1", y="NMDS2")+
  theme_cowplot()+
  theme(legend.position="none",
        axis.title=element_text(size=18),
        axis.text=element_text(size=16))

figure_4_d <- ggordiplots::gg_ordiplot(trait_mds, groups=comm$trapWeek)$plot+
  geom_text(as.data.frame(trait_mds$species),
            mapping=aes(x=MDS1, y=MDS2, label=
                          gsub("..", ".", 
                               gsub("1", "Fav. Human", gsub("0", "Unfav. Human", 
                                                            gsub("Unknown", "", 
                                                                 gsub(".*_", "", 
                                                                      rownames(trait_mds$species))))), fixed=TRUE)), alpha=0.5,
            size=3.5)+
  colorspace::scale_color_discrete_diverging(palette="Berlin", name="Trap Week")+
  labs(x="NMDS1", y="")+
  theme_cowplot()+
  theme(legend.position=c(0.1,0.15),
        legend.direction="horizontal",
        axis.title=element_text(size=18),
        axis.text=element_text(size=16))

figure_4 <- cowplot::plot_grid(figure_4_a, figure_4_b, figure_4_c, figure_4_d,
                               ncol=2, nrow=2, labels=c("(a)", "(b)", "(c)", "(d)"), align="hv")
ggsave2("figure_4.png", figure_4, dpi=400, height=10, width=10)

# Supplemental Figure 6
stressplot(tax_mds)
stressplot(trait_mds)

# Save everything to a .RData file
save.image("mySavedSession.RData")


